@@ -68,11 +68,11 @@ ggbarstats <- function(data,
                        ggplot.component = NULL,
                        output = "plot",
                        ...) {
+  # make sure both quoted and unquoted arguments are allowed
+  c(x, y) %<-% c(rlang::ensym(x), rlang::ensym(y))
 
-  # ensure the variables work quoted or unquoted
-  x <- rlang::ensym(x)
-  y <- rlang::ensym(y)
-  counts <- if (!rlang::quo_is_null(rlang::enquo(counts))) rlang::ensym(counts)
+  # this is currently not supported in `BayesFactor`
+  if (isTRUE(paired)) bf.message <- FALSE
 
   # ================= extracting column names as labels  =====================
 
@@ -86,25 +86,14 @@ ggbarstats <- function(data,
 
   # creating a dataframe
   data %<>%
-    dplyr::select(.data = ., {{ x }}, {{ y }}, {{ counts }}) %>%
+    dplyr::select(.data = ., {{ x }}, {{ y }}, .counts = {{ counts }}) %>%
     tidyr::drop_na(data = .) %>%
     as_tibble(x = .)
 
-  # =========================== converting counts ============================
-
   # untable the dataframe based on the count for each observation
-  if (!rlang::quo_is_null(rlang::enquo(counts))) {
-    data %<>%
-      tidyr::uncount(
-        data = .,
-        weights = {{ counts }},
-        .remove = TRUE,
-        .id = "id"
-      )
-  }
+  if (".counts" %in% names(data)) data %<>% tidyr::uncount(data = ., weights = .counts)
 
-  # x and y need to be a factor for this analysis
-  # also drop the unused levels of the factors
+  # x and y need to be a factor; also drop the unused levels of the factors
   data %<>%
     dplyr::mutate(
       {{ x }} := droplevels(as.factor({{ x }})),
@@ -156,41 +145,19 @@ ggbarstats <- function(data,
     }
   }
 
-  # ============================ percentage dataframe ========================
-
-  # convert the data into percentages; group by yal variable
-  # dataframe with summary labels
-  df <-
-    cat_label_df(
-      data = cat_counter(data = data, x = {{ x }}, y = {{ y }}),
-      label.content = label,
-      perc.k = perc.k
-    )
-
-  # dataframe containing all details needed for sample size and prop test
-  df_labels <-
-    df_facet_label(
-      data = data,
-      x = {{ x }},
-      y = {{ y }},
-      k = k
-    )
-
-  # reorder the category factor levels to order the legend
-  df %<>% dplyr::mutate(.data = ., {{ x }} := factor({{ x }}, unique({{ x }})))
-
   # return early if anything other than plot
   if (output != "plot") {
-    return(switch(
-      EXPR = output,
-      "subtitle" = subtitle,
-      "caption" = caption,
-      "proptest" = df_labels
-    ))
+    return(switch(EXPR = output, "caption" = caption, subtitle))
   }
 
   # =================================== plot =================================
 
+  # dataframe with summary labels
+  df_descriptive <- df_descriptive(data, {{ x }}, {{ y }}, label, perc.k)
+
+  # dataframe containing all details needed for prop test
+  df_proptest <- df_proptest(data, {{ x }}, {{ y }}, k)
+
   # if no. of factor levels is greater than the default palette color count
   palette_message(
     package = package,
@@ -201,7 +168,7 @@ ggbarstats <- function(data,
   # plot
   p <-
     ggplot2::ggplot(
-      data = df,
+      data = df_descriptive,
       mapping = ggplot2::aes(x = {{ y }}, y = perc, fill = {{ x }})
     ) +
     ggplot2::geom_bar(
@@ -217,7 +184,7 @@ ggbarstats <- function(data,
     ) +
     rlang::exec(
       .fn = ggplot2::geom_label,
-      mapping = ggplot2::aes(label = label, group = {{ x }}),
+      mapping = ggplot2::aes(label = .label, group = {{ x }}),
       show.legend = FALSE,
       position = ggplot2::position_fill(vjust = 0.5),
       na.rm = TRUE,
@@ -235,15 +202,11 @@ ggbarstats <- function(data,
     # modify plot
     p <- p +
       ggplot2::geom_text(
-        data = df_labels,
-        mapping = ggplot2::aes(
-          x = {{ y }},
-          y = 1.05,
-          label = significance,
-          fill = NULL
-        ),
-        size = 5,
-        na.rm = TRUE
+        data = df_proptest,
+        mapping = ggplot2::aes(x = {{ y }}, y = 1.05, label = .p.label, fill = NULL),
+        size = 2.8,
+        na.rm = TRUE,
+        parse = TRUE
       )
   }
 
@@ -251,13 +214,8 @@ ggbarstats <- function(data,
   if (isTRUE(sample.size.label)) {
     p <- p +
       ggplot2::geom_text(
-        data = df_labels,
-        mapping = ggplot2::aes(
-          x = {{ y }},
-          y = -0.05,
-          label = N,
-          fill = NULL
-        ),
+        data = df_proptest,
+        mapping = ggplot2::aes(x = {{ y }}, y = -0.05, label = N, fill = NULL),
         size = 4,
         na.rm = TRUE
       )
